package Smolder;

our $VERSION = '1.39';

1;

__END__

=head1 NAME 

Smolder - Web-based Continuous Integration Smoke Server

=head1 SYNOPSIS

Start your smolder server:

    ]$ smolder

=head1 DESCRIPTION

If you have a better idea for what Smolder is and how I can describe it, I'm all ears :)

Please see L<Smolder::Manual> for how to use it.

=head2 SUPPORT

=over

=item * Source Code

L<https://github.com/mpeters/smolder/>

=item * Bugs and Requests

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Smolder>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Smolder>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Smolder>

=item * Search CPAN

L<http://search.cpan.org/dist/Smolder/>

=back

=head1 COPYRIGHT & LICENSE

Copyright 2009 Michael Peters, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

